==> dojo-1.9.2.jar: META-INF/resources/webjars/dojo/1.9.2/cldr/nls/fi/gregorian.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"months-format-narrow": [
		"T",
		"H",
		"M",
		"H",
		"T",
		"K",
		"H",
		"E",
		"S",
		"L",
		"M",
		"J"
	],
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "viikonpäivä",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E d.M.y",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "ccc d. MMM",
	"eraNarrow": [
		"eK",
		"jK"
	],
	"dateFormatItem-yMM": "M.y",
	"days-format-short": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"dateFormat-long": "d. MMMM y",
	"months-format-wide": [
		"tammikuuta",
		"helmikuuta",
		"maaliskuuta",
		"huhtikuuta",
		"toukokuuta",
		"kesäkuuta",
		"heinäkuuta",
		"elokuuta",
		"syyskuuta",
		"lokakuuta",
		"marraskuuta",
		"joulukuuta"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "ip.",
	"dateFormat-full": "cccc d. MMMM y",
	"dateFormatItem-Md": "d.M.",
	"dayPeriods-standAlone-wide-pm": "ip.",
	"dayPeriods-format-abbr-am": "ap.",
	"dateFormatItem-yMd": "d.M.y",
	"dateFormatItem-yM": "L.y",
	"field-era": "aikakausi",
	"months-standAlone-wide": [
		"tammikuu",
		"helmikuu",
		"maaliskuu",
		"huhtikuu",
		"toukokuu",
		"kesäkuu",
		"heinäkuu",
		"elokuu",
		"syyskuu",
		"lokakuu",
		"marraskuu",
		"joulukuu"
	],
	"timeFormat-short": "H.mm",
	"quarters-format-wide": [
		"1. neljännes",
		"2. neljännes",
		"3. neljännes",
		"4. neljännes"
	],
	"timeFormat-long": "H.mm.ss z",
	"dateFormatItem-yMMM": "LLL y",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-year": "vuosi",
	"field-hour": "tunti",
	"months-format-abbr": [
		"tammikuuta",
		"helmikuuta",
		"maaliskuuta",
		"huhtikuuta",
		"toukokuuta",
		"kesäkuuta",
		"heinäkuuta",
		"elokuuta",
		"syyskuuta",
		"lokakuuta",
		"marraskuuta",
		"joulukuuta"
	],
	"timeFormat-full": "H.mm.ss zzzz",
	"field-day-relative+0": "tänään",
	"field-day-relative+1": "huomenna",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "ylihuomenna",
	"dateFormatItem-H": "H",
	"months-standAlone-abbr": [
		"tammi",
		"helmi",
		"maalis",
		"huhti",
		"touko",
		"kesä",
		"heinä",
		"elo",
		"syys",
		"loka",
		"marras",
		"joulu"
	],
	"quarters-format-abbr": [
		"1. nelj.",
		"2. nelj.",
		"3. nelj.",
		"4. nelj."
	],
	"quarters-standAlone-wide": [
		"1. neljännes",
		"2. neljännes",
		"3. neljännes",
		"4. neljännes"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"sunnuntai",
		"maanantai",
		"tiistai",
		"keskiviikko",
		"torstai",
		"perjantai",
		"lauantai"
	],
	"timeFormat-medium": "H.mm.ss",
	"dateFormatItem-Hm": "H.mm",
	"quarters-standAlone-abbr": [
		"1. nelj.",
		"2. nelj.",
		"3. nelj.",
		"4. nelj."
	],
	"eraAbbr": [
		"eKr.",
		"jKr."
	],
	"field-minute": "minuutti",
	"field-dayperiod": "vuorokaudenaika",
	"days-standAlone-abbr": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "eilen",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"dayPeriods-format-narrow-am": "ap.",
	"field-day-relative+-2": "toissapäivänä",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d.M.",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-yMMMM": "LLLL y",
	"dateFormatItem-yMMMMccccd": "cccc d. MMMM y",
	"field-day": "päivä",
	"days-format-wide": [
		"sunnuntaina",
		"maanantaina",
		"tiistaina",
		"keskiviikkona",
		"torstaina",
		"perjantaina",
		"lauantaina"
	],
	"field-zone": "aikavyöhyke",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"T",
		"H",
		"M",
		"H",
		"T",
		"K",
		"H",
		"E",
		"S",
		"L",
		"M",
		"J"
	],
	"field-year-relative+-1": "viime vuonna",
	"field-month-relative+-1": "viime kuussa",
	"dateFormatItem-hm": "h.mm a",
	"dayPeriods-format-abbr-pm": "ip.",
	"days-format-abbr": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"dateFormatItem-yMMMd": "d. MMM y",
	"eraNames": [
		"ennen Kristuksen syntymää",
		"jälkeen Kristuksen syntymän"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"K",
		"T",
		"P",
		"L"
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"K",
		"T",
		"P",
		"L"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "kuukausi",
	"dayPeriods-format-wide-am": "ap.",
	"dayPeriods-standAlone-wide-am": "ap.",
	"dateFormat-short": "d.M.y",
	"field-second": "sekunti",
	"dateFormatItem-yMMMEd": "E d. MMM y",
	"field-month-relative+0": "tässä kuussa",
	"field-month-relative+1": "ensi kuussa",
	"dateFormatItem-Ed": "E d.",
	"field-week": "viikko",
	"dateFormat-medium": "d.M.y",
	"field-year-relative+0": "tänä vuonna",
	"field-week-relative+-1": "viime viikolla",
	"field-year-relative+1": "ensi vuonna",
	"dayPeriods-format-narrow-pm": "ip.",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "H.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-week-relative+0": "tällä viikolla",
	"field-week-relative+1": "ensi viikolla"
}
//end v1.x content
);

==> dojo-1.13.0.jar: META-INF/resources/webjars/dojo/1.13.0/cldr/nls/fi/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h.mm a",
	"days-standAlone-short": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"months-format-narrow": [
		"T",
		"H",
		"M",
		"H",
		"T",
		"K",
		"H",
		"E",
		"S",
		"L",
		"M",
		"J"
	],
	"field-second-relative+0": "nyt",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "viikonpäivä",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E d.M.y",
	"field-wed-relative+0": "tänä keskiviikkona",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "ccc d. MMM",
	"field-wed-relative+1": "ensi keskiviikkona",
	"eraNarrow": [
		"eK",
		"jK"
	],
	"dateFormatItem-yMM": "M.y",
	"field-tue-relative+-1": "viime tiistaina",
	"days-format-short": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"dateFormat-long": "d. MMMM y",
	"field-fri-relative+-1": "viime perjantaina",
	"field-wed-relative+-1": "viime keskiviikkona",
	"months-format-wide": [
		"tammikuuta",
		"helmikuuta",
		"maaliskuuta",
		"huhtikuuta",
		"toukokuuta",
		"kesäkuuta",
		"heinäkuuta",
		"elokuuta",
		"syyskuuta",
		"lokakuuta",
		"marraskuuta",
		"joulukuuta"
	],
	"dateTimeFormat-medium": "{1} 'klo' {0}",
	"dayPeriods-format-wide-pm": "ip.",
	"dateFormat-full": "cccc d. MMMM y",
	"field-thu-relative+-1": "viime torstaina",
	"dateFormatItem-Md": "d.M.",
	"dayPeriods-standAlone-wide-pm": "ip.",
	"dayPeriods-format-abbr-am": "ap.",
	"dateFormatItem-yMd": "d.M.y",
	"dateFormatItem-yM": "L.y",
	"field-era": "aikakausi",
	"months-standAlone-wide": [
		"tammikuu",
		"helmikuu",
		"maaliskuu",
		"huhtikuu",
		"toukokuu",
		"kesäkuu",
		"heinäkuu",
		"elokuu",
		"syyskuu",
		"lokakuu",
		"marraskuu",
		"joulukuu"
	],
	"timeFormat-short": "H.mm",
	"quarters-format-wide": [
		"1. neljännes",
		"2. neljännes",
		"3. neljännes",
		"4. neljännes"
	],
	"timeFormat-long": "H.mm.ss z",
	"dateFormatItem-yMMM": "LLL y",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-year": "vuosi",
	"field-hour": "tunti",
	"months-format-abbr": [
		"tammikuuta",
		"helmikuuta",
		"maaliskuuta",
		"huhtikuuta",
		"toukokuuta",
		"kesäkuuta",
		"heinäkuuta",
		"elokuuta",
		"syyskuuta",
		"lokakuuta",
		"marraskuuta",
		"joulukuuta"
	],
	"field-sat-relative+0": "tänä lauantaina",
	"field-sat-relative+1": "ensi lauantaina",
	"timeFormat-full": "H.mm.ss zzzz",
	"field-day-relative+0": "tänään",
	"field-day-relative+1": "huomenna",
	"field-thu-relative+0": "tänä torstaina",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "ylihuomenna",
	"field-thu-relative+1": "ensi torstaina",
	"dateFormatItem-H": "H",
	"months-standAlone-abbr": [
		"tammi",
		"helmi",
		"maalis",
		"huhti",
		"touko",
		"kesä",
		"heinä",
		"elo",
		"syys",
		"loka",
		"marras",
		"joulu"
	],
	"quarters-format-abbr": [
		"1. nelj.",
		"2. nelj.",
		"3. nelj.",
		"4. nelj."
	],
	"quarters-standAlone-wide": [
		"1. neljännes",
		"2. neljännes",
		"3. neljännes",
		"4. neljännes"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"sunnuntai",
		"maanantai",
		"tiistai",
		"keskiviikko",
		"torstai",
		"perjantai",
		"lauantai"
	],
	"timeFormat-medium": "H.mm.ss",
	"field-sun-relative+0": "tänä sunnuntaina",
	"dateFormatItem-Hm": "H.mm",
	"quarters-standAlone-abbr": [
		"1. nelj.",
		"2. nelj.",
		"3. nelj.",
		"4. nelj."
	],
	"field-sun-relative+1": "ensi sunnuntaina",
	"eraAbbr": [
		"eKr.",
		"jKr."
	],
	"field-minute": "minuutti",
	"field-dayperiod": "vuorokaudenaika",
	"days-standAlone-abbr": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "m.ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "eilen",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} 'klo' {0}",
	"dayPeriods-format-narrow-am": "ap.",
	"field-day-relative+-2": "toissa päivänä",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d.M.",
	"dateTimeFormat-full": "{1} 'klo' {0}",
	"field-fri-relative+0": "tänä perjantaina",
	"dateFormatItem-yMMMM": "LLLL y",
	"field-fri-relative+1": "ensi perjantaina",
	"dateFormatItem-yMMMMccccd": "cccc d. MMMM y",
	"field-day": "päivä",
	"days-format-wide": [
		"sunnuntaina",
		"maanantaina",
		"tiistaina",
		"keskiviikkona",
		"torstaina",
		"perjantaina",
		"lauantaina"
	],
	"field-zone": "aikavyöhyke",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"T",
		"H",
		"M",
		"H",
		"T",
		"K",
		"H",
		"E",
		"S",
		"L",
		"M",
		"J"
	],
	"field-year-relative+-1": "viime vuonna",
	"field-month-relative+-1": "viime kuussa",
	"dateFormatItem-hm": "h.mm a",
	"dayPeriods-format-abbr-pm": "ip.",
	"days-format-abbr": [
		"su",
		"ma",
		"ti",
		"ke",
		"to",
		"pe",
		"la"
	],
	"eraNames": [
		"ennen Kristuksen syntymää",
		"jälkeen Kristuksen syntymän"
	],
	"dateFormatItem-yMMMd": "d. MMM y",
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"K",
		"T",
		"P",
		"L"
	],
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"K",
		"T",
		"P",
		"L"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "kuukausi",
	"field-tue-relative+0": "tänä tiistaina",
	"field-tue-relative+1": "ensi tiistaina",
	"dayPeriods-format-wide-am": "ap.",
	"dayPeriods-standAlone-wide-am": "ap.",
	"dateFormatItem-EHm": "E H.mm",
	"field-mon-relative+0": "tänä maanantaina",
	"field-mon-relative+1": "ensi maanantaina",
	"dateFormat-short": "d.M.y",
	"dateFormatItem-EHms": "E H.mm.ss",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"field-second": "sekunti",
	"field-sat-relative+-1": "viime lauantaina",
	"dateFormatItem-yMMMEd": "E d. MMM y",
	"field-sun-relative+-1": "viime sunnuntaina",
	"field-month-relative+0": "tässä kuussa",
	"field-month-relative+1": "ensi kuussa",
	"dateFormatItem-Ed": "E d.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "viikko",
	"dateFormat-medium": "d.M.y",
	"field-year-relative+0": "tänä vuonna",
	"field-week-relative+-1": "viime viikolla",
	"field-year-relative+1": "ensi vuonna",
	"dayPeriods-format-narrow-pm": "ip.",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "H.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-mon-relative+-1": "viime maanantaina",
	"field-week-relative+0": "tällä viikolla",
	"field-week-relative+1": "ensi viikolla"
}
//end v1.x content
);
